header.format

# XMLRésuméLibrary: User Guide

css.href | XSL Parameter Reference | interest.description.format

## Name

header.format — controls formatting of the `header` element

## Applies To

This parameter controls the formatting of the `header` element in HTML and text output formats. The FO/PDF formatter is not affected by this parameter; it produces output similar to the `centered` option, but with the text left-justified within a centered block.

## Possible Values

Possible values include `standard` (the default) and `centered`.

`standard`

  Produces a centered line with the name and the word “Résumé”, followed by a left-justified contact information block:

  `Jo Doe - Résumé
  Contact Information:
  Jo Doe
  123 Elm #456
  Garbonzoville, NX 99999-9999
  Phone: 555.555.5555
  Email: doe@doe.doe
  URL: http://doe.com/~doe/`

  This value is the default for `header.format`.

`centered`

  Produces a single centered block with the name and contact information.

  `Jo Doe
  123 Elm #456
  Garbonzoville, NX 99999-9999
  Phone: 555.555.5555
  Email: doe@doe.doe
  URL: http://doe.com/~doe/`

css.href | XSL Parameter Reference | interest.description.format